# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jetpack/proto/runtime/v1alpha1/task.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from jetpack.proto.runtime.v1alpha1 import remote_pb2 as jetpack_dot_proto_dot_runtime_dot_v1alpha1_dot_remote__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)jetpack/proto/runtime/v1alpha1/task.proto\x12\x04task\x1a+jetpack/proto/runtime/v1alpha1/remote.proto\"\x9c\x05\n\rPersistedTask\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12)\n\x10qualified_symbol\x18\x02 \x01(\tR\x0fqualifiedSymbol\x12!\n\x0c\x65ncoded_args\x18\x03 \x01(\x0cR\x0b\x65ncodedArgs\x12\x1a\n\x08manifest\x18\x04 \x01(\x0cR\x08manifest\x12\x32\n\x06status\x18\x05 \x01(\x0e\x32\x1a.task.PersistedTask.StatusR\x06status\x12&\n\x06result\x18\x06 \x01(\x0b\x32\x0e.remote.ResultR\x06result\x12\x19\n\x08\x61pp_name\x18\x07 \x01(\tR\x07\x61ppName\x12$\n\x0eparent_task_id\x18\x08 \x01(\tR\x0cparentTaskId\x12-\n\x12with_checkpointing\x18\t \x01(\x08R\x11withCheckpointing\x12+\n\x11\x63urrent_iteration\x18\n \x01(\x05R\x10\x63urrentIteration\x12H\n\x0e\x65xecution_mode\x18\x0b \x01(\x0e\x32!.task.PersistedTask.ExecutionModeR\rexecutionMode\"\x8e\x01\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07WAITING\x10\x02\x12\t\n\x05READY\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\r\n\tSUCCEEDED\x10\x05\x12\x0e\n\nCANCELLING\x10\x06\x12\r\n\tCANCELLED\x10\x07\x12\x0b\n\x07\x46\x41ILING\x10\x08\x12\n\n\x06\x46\x41ILED\x10\t\"=\n\rExecutionMode\x12\x11\n\rEXECUTION_JOB\x10\x00\x12\x19\n\x15\x45XECUTION_WORKER_PUSH\x10\x01\"\xaf\x01\n\x11\x43heckpointTracker\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12J\n\x0b\x63heckpoints\x18\x02 \x03(\x0b\x32(.task.CheckpointTracker.CheckpointsEntryR\x0b\x63heckpoints\x1a>\n\x10\x43heckpointsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42y\n\x08\x63om.taskB\tTaskProtoP\x01Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\xa2\x02\x03TXX\xaa\x02\x04Task\xca\x02\x04Task\xe2\x02\x10Task\\GPBMetadata\xea\x02\x04Taskb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jetpack.proto.runtime.v1alpha1.task_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\010com.taskB\tTaskProtoP\001Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\242\002\003TXX\252\002\004Task\312\002\004Task\342\002\020Task\\GPBMetadata\352\002\004Task'
  _CHECKPOINTTRACKER_CHECKPOINTSENTRY._options = None
  _CHECKPOINTTRACKER_CHECKPOINTSENTRY._serialized_options = b'8\001'
  _PERSISTEDTASK._serialized_start=97
  _PERSISTEDTASK._serialized_end=765
  _PERSISTEDTASK_STATUS._serialized_start=560
  _PERSISTEDTASK_STATUS._serialized_end=702
  _PERSISTEDTASK_EXECUTIONMODE._serialized_start=704
  _PERSISTEDTASK_EXECUTIONMODE._serialized_end=765
  _CHECKPOINTTRACKER._serialized_start=768
  _CHECKPOINTTRACKER._serialized_end=943
  _CHECKPOINTTRACKER_CHECKPOINTSENTRY._serialized_start=881
  _CHECKPOINTTRACKER_CHECKPOINTSENTRY._serialized_end=943
# @@protoc_insertion_point(module_scope)
