# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jetpack/proto/runtime/v1alpha1/jetworker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.jetpack/proto/runtime/v1alpha1/jetworker.proto\x12\tjetworker\"\x7f\n\x16StartJetroutineRequest\x12\x17\n\x07\x65xec_id\x18\x01 \x01(\tR\x06\x65xecId\x12)\n\x10qualified_symbol\x18\x02 \x01(\tR\x0fqualifiedSymbol\x12!\n\x0c\x65ncoded_args\x18\x03 \x01(\tR\x0b\x65ncodedArgs\"\x19\n\x17StartJetroutineResponse2g\n\tJetworker\x12Z\n\x0fStartJetroutine\x12!.jetworker.StartJetroutineRequest\x1a\".jetworker.StartJetroutineResponse\"\x00\x42\x97\x01\n\rcom.jetworkerB\x0eJetworkerProtoP\x01Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\xa2\x02\x03JXX\xaa\x02\tJetworker\xca\x02\tJetworker\xe2\x02\x15Jetworker\\GPBMetadata\xea\x02\tJetworkerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jetpack.proto.runtime.v1alpha1.jetworker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.jetworkerB\016JetworkerProtoP\001Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\242\002\003JXX\252\002\tJetworker\312\002\tJetworker\342\002\025Jetworker\\GPBMetadata\352\002\tJetworker'
  _STARTJETROUTINEREQUEST._serialized_start=61
  _STARTJETROUTINEREQUEST._serialized_end=188
  _STARTJETROUTINERESPONSE._serialized_start=190
  _STARTJETROUTINERESPONSE._serialized_end=215
  _JETWORKER._serialized_start=217
  _JETWORKER._serialized_end=320
# @@protoc_insertion_point(module_scope)
