# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jetpack/proto/runtime/v1alpha1/remote.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+jetpack/proto/runtime/v1alpha1/remote.proto\x12\x06remote\x1a\x1fgoogle/protobuf/timestamp.proto\"[\n\x11RemoteCallRequest\x12)\n\x10qualified_symbol\x18\x01 \x01(\tR\x0fqualifiedSymbol\x12\x1b\n\tjson_args\x18\x02 \x01(\tR\x08jsonArgs\"7\n\x12RemoteCallResponse\x12!\n\x0cjson_results\x18\x01 \x01(\tR\x0bjsonResults\"Z\n\x11\x43reateTaskRequest\x12 \n\x04task\x18\x01 \x01(\x0b\x32\x0c.remote.TaskR\x04task\x12#\n\x0bsdk_version\x18\x02 \x01(\tB\x02\x18\x01R\nsdkVersion\"-\n\x12\x43reateTaskResponse\x12\x17\n\x07task_id\x18\x01 \x01(\tR\x06taskId\",\n\x11\x43\x61ncelTaskRequest\x12\x17\n\x07task_id\x18\x01 \x01(\tR\x06taskId\".\n\x12\x43\x61ncelTaskResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"T\n\x11PostResultRequest\x12\x17\n\x07\x65xec_id\x18\x01 \x01(\tR\x06\x65xecId\x12&\n\x06result\x18\x02 \x01(\x0b\x32\x0e.remote.ResultR\x06result\"\x14\n\x12PostResultResponse\"\xff\x02\n\x04Task\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\x1e\n\x08hostname\x18\x06 \x01(\tB\x02\x18\x01R\x08hostname\x12\x19\n\x08\x61pp_name\x18\n \x01(\tR\x07\x61ppName\x12%\n\x0e\x63hart_revision\x18\x0b \x01(\tR\rchartRevision\x12)\n\x10qualified_symbol\x18\x02 \x01(\tR\x0fqualifiedSymbol\x12!\n\x0c\x65ncoded_args\x18\x04 \x01(\x0cR\x0b\x65ncodedArgs\x12$\n\x0eparent_task_id\x18\x05 \x01(\tR\x0cparentTaskId\x12;\n\x0btarget_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ntargetTime\x12-\n\x12with_checkpointing\x18\t \x01(\x08R\x11withCheckpointing\x12\x17\n\x07task_id\x18\x08 \x01(\tR\x06taskId\"R\n\x06Result\x12#\n\x05value\x18\x01 \x01(\x0b\x32\r.remote.ValueR\x05value\x12#\n\x05\x65rror\x18\x02 \x01(\x0b\x32\r.remote.ErrorR\x05\x65rror\"m\n\x05\x45rror\x12%\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x11.remote.ErrorCodeR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12#\n\rencoded_error\x18\x03 \x01(\x0cR\x0c\x65ncodedError\",\n\x05Value\x12#\n\rencoded_value\x18\x01 \x01(\x0cR\x0c\x65ncodedValue\"\xb0\x02\n\x12RegisterAppRequest\x12\x1c\n\tnamespace\x18\x01 \x01(\tR\tnamespace\x12\x1a\n\x08hostname\x18\x02 \x01(\tR\x08hostname\x12,\n\tcron_jobs\x18\x04 \x03(\x0b\x32\x0f.remote.CronJobR\x08\x63ronJobs\x12+\n\x11qualified_symbols\x18\x05 \x03(\tR\x10qualifiedSymbols\x12G\n\tendpoints\x18\x06 \x03(\x0b\x32).remote.RegisterAppRequest.EndpointsEntryR\tendpoints\x1a<\n\x0e\x45ndpointsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x15\n\x13RegisterAppResponse\"P\n\x14\x44\x65registerAppRequest\x12\x1c\n\tnamespace\x18\x01 \x01(\tR\tnamespace\x12\x1a\n\x08hostname\x18\x02 \x01(\tR\x08hostname\"\x17\n\x15\x44\x65registerAppResponse\"/\n\x14WaitForResultRequest\x12\x17\n\x07task_id\x18\x01 \x01(\tR\x06taskId\"?\n\x15WaitForResultResponse\x12&\n\x06result\x18\x01 \x01(\x0b\x32\x0e.remote.ResultR\x06result\":\n\x1cGetSymbolFromEndpointRequest\x12\x1a\n\x08\x65ndpoint\x18\x01 \x01(\tR\x08\x65ndpoint\"7\n\x1dGetSymbolFromEndpointResponse\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\"\xf8\x01\n\x07\x43ronJob\x12)\n\x10qualified_symbol\x18\x03 \x01(\tR\x0fqualifiedSymbol\x12\x1f\n\x0btarget_time\x18\x04 \x01(\tR\ntargetTime\x12>\n\x12target_day_of_week\x18\x05 \x01(\x0e\x32\x11.remote.DayOfWeekR\x0ftargetDayOfWeek\x12 \n\x04unit\x18\x06 \x01(\x0e\x32\x0c.remote.UnitR\x04unit\x12\x1a\n\x08interval\x18\x07 \x01(\x03R\x08interval\x12#\n\rschedule_rule\x18\x08 \x01(\tR\x0cscheduleRule\")\n\x0eGetTaskRequest\x12\x17\n\x07task_id\x18\x01 \x01(\tR\x06taskId\"D\n\x0fGetTaskResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x65ncoded_args\x18\x02 \x01(\x0cR\x0b\x65ncodedArgs*6\n\tErrorCode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06SYSTEM\x10\x64\x12\x10\n\x0b\x41PPLICATION\x10\xc8\x01*R\n\x04Unit\x12\x10\n\x0cUNKNOWN_UNIT\x10\x00\x12\x0b\n\x07SECONDS\x10\x01\x12\x0b\n\x07MINUTES\x10\x02\x12\t\n\x05HOURS\x10\x03\x12\x08\n\x04\x44\x41YS\x10\x04\x12\t\n\x05WEEKS\x10\x05*x\n\tDayOfWeek\x12\x0f\n\x0bUNKNOWN_DAY\x10\x00\x12\n\n\x06SUNDAY\x10\x01\x12\n\n\x06MONDAY\x10\x02\x12\x0b\n\x07TUESDAY\x10\x03\x12\r\n\tWEDNESDAY\x10\x04\x12\x0c\n\x08THURSDAY\x10\x05\x12\n\n\x06\x46RIDAY\x10\x06\x12\x0c\n\x08SATURDAY\x10\x07\x32\xbc\x05\n\x0eRemoteExecutor\x12\x45\n\nCreateTask\x12\x19.remote.CreateTaskRequest\x1a\x1a.remote.CreateTaskResponse\"\x00\x12\x45\n\nCancelTask\x12\x19.remote.CancelTaskRequest\x1a\x1a.remote.CancelTaskResponse\"\x00\x12\x45\n\nPostResult\x12\x19.remote.PostResultRequest\x1a\x1a.remote.PostResultResponse\"\x00\x12N\n\rWaitForResult\x12\x1c.remote.WaitForResultRequest\x1a\x1d.remote.WaitForResultResponse\"\x00\x12<\n\x07GetTask\x12\x16.remote.GetTaskRequest\x1a\x17.remote.GetTaskResponse\"\x00\x12\x66\n\x15GetSymbolFromEndpoint\x12$.remote.GetSymbolFromEndpointRequest\x1a%.remote.GetSymbolFromEndpointResponse\"\x00\x12H\n\x0bRegisterApp\x12\x1a.remote.RegisterAppRequest\x1a\x1b.remote.RegisterAppResponse\"\x00\x12N\n\rDeregisterApp\x12\x1c.remote.DeregisterAppRequest\x1a\x1d.remote.DeregisterAppResponse\"\x00\x12\x45\n\nRemoteCall\x12\x19.remote.RemoteCallRequest\x1a\x1a.remote.RemoteCallResponse\"\x00\x42\x85\x01\n\ncom.remoteB\x0bRemoteProtoP\x01Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\xa2\x02\x03RXX\xaa\x02\x06Remote\xca\x02\x06Remote\xe2\x02\x12Remote\\GPBMetadata\xea\x02\x06Remoteb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jetpack.proto.runtime.v1alpha1.remote_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\ncom.remoteB\013RemoteProtoP\001Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\242\002\003RXX\252\002\006Remote\312\002\006Remote\342\002\022Remote\\GPBMetadata\352\002\006Remote'
  _CREATETASKREQUEST.fields_by_name['sdk_version']._options = None
  _CREATETASKREQUEST.fields_by_name['sdk_version']._serialized_options = b'\030\001'
  _TASK.fields_by_name['hostname']._options = None
  _TASK.fields_by_name['hostname']._serialized_options = b'\030\001'
  _REGISTERAPPREQUEST_ENDPOINTSENTRY._options = None
  _REGISTERAPPREQUEST_ENDPOINTSENTRY._serialized_options = b'8\001'
  _ERRORCODE._serialized_start=2238
  _ERRORCODE._serialized_end=2292
  _UNIT._serialized_start=2294
  _UNIT._serialized_end=2376
  _DAYOFWEEK._serialized_start=2378
  _DAYOFWEEK._serialized_end=2498
  _REMOTECALLREQUEST._serialized_start=88
  _REMOTECALLREQUEST._serialized_end=179
  _REMOTECALLRESPONSE._serialized_start=181
  _REMOTECALLRESPONSE._serialized_end=236
  _CREATETASKREQUEST._serialized_start=238
  _CREATETASKREQUEST._serialized_end=328
  _CREATETASKRESPONSE._serialized_start=330
  _CREATETASKRESPONSE._serialized_end=375
  _CANCELTASKREQUEST._serialized_start=377
  _CANCELTASKREQUEST._serialized_end=421
  _CANCELTASKRESPONSE._serialized_start=423
  _CANCELTASKRESPONSE._serialized_end=469
  _POSTRESULTREQUEST._serialized_start=471
  _POSTRESULTREQUEST._serialized_end=555
  _POSTRESULTRESPONSE._serialized_start=557
  _POSTRESULTRESPONSE._serialized_end=577
  _TASK._serialized_start=580
  _TASK._serialized_end=963
  _RESULT._serialized_start=965
  _RESULT._serialized_end=1047
  _ERROR._serialized_start=1049
  _ERROR._serialized_end=1158
  _VALUE._serialized_start=1160
  _VALUE._serialized_end=1204
  _REGISTERAPPREQUEST._serialized_start=1207
  _REGISTERAPPREQUEST._serialized_end=1511
  _REGISTERAPPREQUEST_ENDPOINTSENTRY._serialized_start=1451
  _REGISTERAPPREQUEST_ENDPOINTSENTRY._serialized_end=1511
  _REGISTERAPPRESPONSE._serialized_start=1513
  _REGISTERAPPRESPONSE._serialized_end=1534
  _DEREGISTERAPPREQUEST._serialized_start=1536
  _DEREGISTERAPPREQUEST._serialized_end=1616
  _DEREGISTERAPPRESPONSE._serialized_start=1618
  _DEREGISTERAPPRESPONSE._serialized_end=1641
  _WAITFORRESULTREQUEST._serialized_start=1643
  _WAITFORRESULTREQUEST._serialized_end=1690
  _WAITFORRESULTRESPONSE._serialized_start=1692
  _WAITFORRESULTRESPONSE._serialized_end=1755
  _GETSYMBOLFROMENDPOINTREQUEST._serialized_start=1757
  _GETSYMBOLFROMENDPOINTREQUEST._serialized_end=1815
  _GETSYMBOLFROMENDPOINTRESPONSE._serialized_start=1817
  _GETSYMBOLFROMENDPOINTRESPONSE._serialized_end=1872
  _CRONJOB._serialized_start=1875
  _CRONJOB._serialized_end=2123
  _GETTASKREQUEST._serialized_start=2125
  _GETTASKREQUEST._serialized_end=2166
  _GETTASKRESPONSE._serialized_start=2168
  _GETTASKRESPONSE._serialized_end=2236
  _REMOTEEXECUTOR._serialized_start=2501
  _REMOTEEXECUTOR._serialized_end=3201
# @@protoc_insertion_point(module_scope)
