"""
Submodule for running, scheduling, and managing Jetroutines
"""

from typing import Dict

from jetpack.core._task import Task

__pdoc__: Dict[str, bool] = {}

__pdoc__["_jetroutine"] = True
__pdoc__["_task"] = True
